#!/usr/bin/env python3
import mechanicalsoup

def go_duck(query):

    # Connect to duckduckgo
    browser = mechanicalsoup.StatefulBrowser()
    browser.set_user_agent('Mozilla/5.0 (X11; Linux x86_64; rv:60.0) Gecko/20100101 Firefox/60.0')
    browser.open(f"https://duckduckgo.com/html/?q={query}")
    
    # List 
    list1 = []

    # Subfunction
    def change_page():
        browser.select_form(browser.get_current_page().select('form')[-1])
        browser.submit_selected()
        read_urls()


    def check():
        if browser.get_current_page().select('.btn--alt'):
            change_page()

    def read_urls():
        for link in browser.get_current_page().select('a.result__url'):
            list1.append(link.text.replace('\n',''))

        check()
        return ', '.join(filter(bool, list1))

    return read_urls().replace(' ','').split(',')



#!/usr/bin/env python3
from getrails.duckduckgo.search import go_duck
from getrails.google.search import go_gle

def search (query):
    try:
        result = go_gle(query)
    except:
        result = go_duck(query)
    return result



#!/usr/bin/env python3
from googlesearch import search, get_random_user_agent

def go_gle (query):
    my_results_list = []
    for i in search(query,        # Expression
                    tld = 'com',  # TL domain
                    lang = 'en',  # Set lang en
                    num = 10,     # Number of results / page
                    start = 0,    # First result to retrieve
                    stop = None,  # Last result to retrieve
                    pause = 0,  # Lapse between HTTP requests
                    user_agent = get_random_user_agent(),
                   ):
        my_results_list.append(i)

    return my_results_list



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name='getrails',
    version=1.8,
    author="Julio Lira",
    author_email="jul10l1r4@disroot.org",
    description="Tool of OSINT and Dork hacking that work with Google and Duckduckgo",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Jul10l1r4/getrailslib",
    packages=["getrails", "getrails.google", "getrails.duckduckgo"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Operating System :: OS Independent",
        ],
    )
